aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--binding/gdbus/ofono_manager.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/binding/gdbus/ofono_manager.c b/binding/gdbus/ofono_manager.c
index 8db5df3..c0000dc 100644
--- a/binding/gdbus/ofono_manager.c
+++ b/binding/gdbus/ofono_manager.c
@@ -71,8 +71,8 @@ int ofono_manager_set_default_modem(const char *address)
type = g_variant_get_string(value, NULL);
}
- /* If not a HFP modem then continue */
- if (g_strcmp0(type, "hfp"))
+ /* If address is set then searching for hfp modem */
+ if (address && g_strcmp0(type, "hfp"))
continue;
/* If address is NULL then use the first modem as default,